(function ($, Drupal, once) {
  'use strict';

  Drupal.behaviors.linkAsPopup = {
    attach: function (context) {

      // Select all links with target="_blank" within the context.
      once('popupAsChromeless', 'a[target="_blank"].link-as-popup.popup-as-chromeless', context).forEach(function (link) {
        // Get the width and height from the data attributes.
        var width = link.getAttribute('data-width');
        var height = link.getAttribute('data-height');
        var mytop = (screen.height) ? Math.ceil((screen.height - height) / 2) : 100;
        var myleft = (screen.width) ? Math.ceil((screen.width - width) / 2) : 100;
        // Get the link text to use as the popup name.
        var title = link.getAttribute('data-title');
        // If width and height are specified, add an event listener.
        if (width && height) {
          link.addEventListener('click', function (event) {
            event.preventDefault();
            var href = link.href;
            // Open a new window with the specified dimensions and the link text as the name.
            var options = 'location=0,status=0,toolbar=0,scrollbars=1,width=' + width + ',height=' + height + ',top=' + mytop + ',left=' + myleft;
            window.open(href, title, options);
          });
        }
      });

      once('popupAsDialog', 'a[target="_blank"].link-as-popup.popup-as-dialog', context).forEach(function (link) {
        $(link).click(function (event) {
          event.preventDefault();
          var width = $(this).attr('data-width');
          var height = $(this).attr('data-height');
          var href = $(this).attr('href');
          var title = $(this).attr('data-title');
          var cleanId = $(this).attr('id');
          $('<div id="'+cleanId+'-wrapper" class="popup-as-dialog-wrapper"></div>').dialog({
            modal: true,
            title: title,
            width: width,
            height: height,
            resizable: true,
            draggable: true,
            create: function () {
              var iframe = $('<iframe>', {
                src: href,
                id: cleanId,
                title: title,
                frameborder: 0,
                width: '100%',
                height: '100%',
                scrolling: 'auto'
              });
              $(this).append(iframe);
            },
            close: function (event, ui) {
              $(this).remove();
            }
          });
        });
      });

    }
  };
})(jQuery, Drupal, once);
